'''
用于计算薪资的模块
'''

company = 'xx公司'
print(company)

def yearsalary(monthsalary):
    '''
    计算年薪，monthsalary*12
    :param monthsalary:传入月薪
    :return:返回年薪
    '''
    return monthsalary*12

def daysalary(monthsalary):
    '''
    计算日薪，22.5天法定工作日
    :param monthsalary:传入月薪
    :return: 返回日薪
    '''
    return monthsalary/22.5


# 测试代码
if __name__ == '__main__':
    print(yearsalary(10000))


# setup设置发行属性
from distutils.core import setup

setup(
    name='lance_issue_mod_text',
    version='1.0',
    description='第一个对外发布项目，测试',
    author='Lance',
    author_email='377544418@qq.com',
    py_modules=['issue_mod.Salary']
)